API Documentation — scikit-hubness 0.21.0a8 documentation

# API Documentation

This is the API documentation for `scikit-hubness`.

## Analysis: `skhubness.analysis`

The `skhubness.analysis` package provides methods for measuring hubness.

`analysis.Hubness` | Examine hubness characteristics of data.

## Neighbors: `skhubness.neighbors`

The `skhubness.neighbors` package is a drop-in replacement for `sklearn.neighbors`, providing all of its features, while adding transparent support for hubness reduction and approximate nearest neighbor search.

`neighbors.BallTree` | BallTree for fast generalized N-point problems
`neighbors.DistanceMetric` | DistanceMetric class
`neighbors.KDTree` | KDTree for fast generalized N-point problems
`neighbors.HNSW` | Wrapper for using nmslib
`neighbors.KNeighborsClassifier` | Classifier implementing the k-nearest neighbors vote.
`neighbors.KNeighborsRegressor` | Regression based on k-nearest neighbors.
`neighbors.FalconnLSH` | Wrapper for using falconn LSH
`neighbors.NearestCentroid` | Nearest centroid classifier.
`neighbors.NearestNeighbors` | Unsupervised learner for implementing neighbor searches.
`neighbors.ONNG` | Wrapper for ngtpy and ONNG
`neighbors.PuffinnLSH` | Wrap Puffinn LSH for scikit-learn compatibility.
`neighbors.RadiusNeighborsClassifier` | Classifier implementing a vote among neighbors within a given radius
`neighbors.RadiusNeighborsRegressor` | Regression based on neighbors within a fixed radius.
`neighbors.RandomProjectionTree` | Wrapper for using annoy.AnnoyIndex
`neighbors.kneighbors_graph` | Computes the (weighted) graph of k-Neighbors for points in X
`neighbors.radius_neighbors_graph` | Computes the (weighted) graph of Neighbors for points in X
`neighbors.KernelDensity` | Kernel Density Estimation
`neighbors.LocalOutlierFactor` | Unsupervised Outlier Detection using Local Outlier Factor (LOF)
`neighbors.NeighborhoodComponentsAnalysis` | Neighborhood Components Analysis

## Reduction: `skhubness.reduction`

The `skhubness.reduction` package provides methods for hubness reduction.

`reduction.MutualProximity` | Hubness reduction with Mutual Proximity [R5a390b9a9956-1].
`reduction.LocalScaling` | Hubness reduction with Local Scaling [Rf1f7cb70176a-1].
`reduction.DisSimLocal` | Hubness reduction with DisSimLocal [R3ede0f1b99b2-1].